==> aws-cdk-scala-lakeformation_3-0.1.4-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html","n":"lakeformation","t":"lakeformation","d":"","k":"static"},
{"l":"io/burkard/cdk/services/lakeformation.html","n":"io.burkard.cdk.services.lakeformation","t":"package io.burkard.cdk.services.lakeformation","d":"io/burkard/cdk/services/lakeformation","k":"package"},
{"l":"io/burkard/cdk/services/lakeformation/CfnDataLakeSettings$.html","n":"CfnDataLakeSettings","t":"object CfnDataLakeSettings","d":"io/burkard/cdk/services/lakeformation/CfnDataLakeSettings$","k":"object"},
{"l":"io/burkard/cdk/services/lakeformation/CfnDataLakeSettings$.html","n":"apply","t":"def apply(internalResourceId: String, admins: Option[List[_]], trustedResourceOwners: Option[List[String]])(implicit stackCtx: Stack): CfnDataLakeSettings","d":"io/burkard/cdk/services/lakeformation/CfnDataLakeSettings$","k":"def"},
{"l":"io/burkard/cdk/services/lakeformation/CfnDataLakeSettingsProps$.html","n":"CfnDataLakeSettingsProps","t":"object CfnDataLakeSettingsProps","d":"io/burkard/cdk/services/lakeformation/CfnDataLakeSettingsProps$","k":"object"},
{"l":"io/burkard/cdk/services/lakeformation/CfnDataLakeSettingsProps$.html","n":"apply","t":"def apply(admins: Option[List[_]], trustedResourceOwners: Option[List[String]]): CfnDataLakeSettingsProps","d":"io/burkard/cdk/services/lakeformation/CfnDataLakeSettingsProps$","k":"def"},
{"l":"io/burkard/cdk/services/lakeformation/CfnPermissions$.html","n":"CfnPermissions","t":"object CfnPermissions","d":"io/burkard/cdk/services/lakeformation/CfnPermissions$","k":"object"},
{"l":"io/burkard/cdk/services/lakeformation/CfnPermissions$.html","n":"apply","t":"def apply(internalResourceId: String, permissionsWithGrantOption: Option[List[String]], dataLakePrincipal: Option[DataLakePrincipalProperty], permissions: Option[List[String]], resource: Option[ResourceProperty])(implicit stackCtx: Stack): CfnPermissions","d":"io/burkard/cdk/services/lakeformation/CfnPermissions$","k":"def"},
{"l":"io/burkard/cdk/services/lakeformation/CfnPermissionsProps$.html","n":"CfnPermissionsProps","t":"object CfnPermissionsProps","d":"io/burkard/cdk/services/lakeformation/CfnPermissionsProps$","k":"object"},
{"l":"io/burkard/cdk/services/lakeformation/CfnPermissionsProps$.html","n":"apply","t":"def apply(permissionsWithGrantOption: Option[List[String]], dataLakePrincipal: Option[DataLakePrincipalProperty], permissions: Option[List[String]], resource: Option[ResourceProperty]): CfnPermissionsProps","d":"io/burkard/cdk/services/lakeformation/CfnPermissionsProps$","k":"def"},
{"l":"io/burkard/cdk/services/lakeformation/CfnResource$.html","n":"CfnResource","t":"object CfnResource","d":"io/burkard/cdk/services/lakeformation/CfnResource$","k":"object"},
{"l":"io/burkard/cdk/services/lakeformation/CfnResource$.html","n":"apply","t":"def apply(internalResourceId: String, resourceArn: Option[String], useServiceLinkedRole: Option[Boolean], roleArn: Option[String])(implicit stackCtx: Stack): CfnResource","d":"io/burkard/cdk/services/lakeformation/CfnResource$","k":"def"},
{"l":"io/burkard/cdk/services/lakeformation/CfnResourceProps$.html","n":"CfnResourceProps","t":"object CfnResourceProps","d":"io/burkard/cdk/services/lakeformation/CfnResourceProps$","k":"object"},
{"l":"io/burkard/cdk/services/lakeformation/CfnResourceProps$.html","n":"apply","t":"def apply(resourceArn: Option[String], useServiceLinkedRole: Option[Boolean], roleArn: Option[String]): CfnResourceProps","d":"io/burkard/cdk/services/lakeformation/CfnResourceProps$","k":"def"},
{"l":"io/burkard/cdk/services/lakeformation/ColumnWildcardProperty$.html","n":"ColumnWildcardProperty","t":"object ColumnWildcardProperty","d":"io/burkard/cdk/services/lakeformation/ColumnWildcardProperty$","k":"object"},
{"l":"io/burkard/cdk/services/lakeformation/ColumnWildcardProperty$.html","n":"apply","t":"def apply(excludedColumnNames: Option[List[String]]): ColumnWildcardProperty","d":"io/burkard/cdk/services/lakeformation/ColumnWildcardProperty$","k":"def"},
{"l":"io/burkard/cdk/services/lakeformation/DataLakePrincipalProperty$.html","n":"DataLakePrincipalProperty","t":"object DataLakePrincipalProperty","d":"io/burkard/cdk/services/lakeformation/DataLakePrincipalProperty$","k":"object"},
{"l":"io/burkard/cdk/services/lakeformation/DataLakePrincipalProperty$.html","n":"apply","t":"def apply(dataLakePrincipalIdentifier: Option[String]): DataLakePrincipalProperty","d":"io/burkard/cdk/services/lakeformation/DataLakePrincipalProperty$","k":"def"},
{"l":"io/burkard/cdk/services/lakeformation/DataLocationResourceProperty$.html","n":"DataLocationResourceProperty","t":"object DataLocationResourceProperty","d":"io/burkard/cdk/services/lakeformation/DataLocationResourceProperty$","k":"object"},
{"l":"io/burkard/cdk/services/lakeformation/DataLocationResourceProperty$.html","n":"apply","t":"def apply(s3Resource: Option[String], catalogId: Option[String]): DataLocationResourceProperty","d":"io/burkard/cdk/services/lakeformation/DataLocationResourceProperty$","k":"def"},
{"l":"io/burkard/cdk/services/lakeformation/DatabaseResourceProperty$.html","n":"DatabaseResourceProperty","t":"object DatabaseResourceProperty","d":"io/burkard/cdk/services/lakeformation/DatabaseResourceProperty$","k":"object"},
{"l":"io/burkard/cdk/services/lakeformation/DatabaseResourceProperty$.html","n":"apply","t":"def apply(name: Option[String], catalogId: Option[String]): DatabaseResourceProperty","d":"io/burkard/cdk/services/lakeformation/DatabaseResourceProperty$","k":"def"},
{"l":"io/burkard/cdk/services/lakeformation/ResourceProperty$.html","n":"ResourceProperty","t":"object ResourceProperty","d":"io/burkard/cdk/services/lakeformation/ResourceProperty$","k":"object"},
{"l":"io/burkard/cdk/services/lakeformation/ResourceProperty$.html","n":"apply","t":"def apply(dataLocationResource: Option[DataLocationResourceProperty], tableWithColumnsResource: Option[TableWithColumnsResourceProperty], tableResource: Option[TableResourceProperty], databaseResource: Option[DatabaseResourceProperty]): ResourceProperty","d":"io/burkard/cdk/services/lakeformation/ResourceProperty$","k":"def"},
{"l":"io/burkard/cdk/services/lakeformation/TableResourceProperty$.html","n":"TableResourceProperty","t":"object TableResourceProperty","d":"io/burkard/cdk/services/lakeformation/TableResourceProperty$","k":"object"},
{"l":"io/burkard/cdk/services/lakeformation/TableResourceProperty$.html","n":"apply","t":"def apply(name: Option[String], tableWildcard: Option[TableWildcardProperty], catalogId: Option[String], databaseName: Option[String]): TableResourceProperty","d":"io/burkard/cdk/services/lakeformation/TableResourceProperty$","k":"def"},
{"l":"io/burkard/cdk/services/lakeformation/TableWildcardProperty$.html","n":"TableWildcardProperty","t":"object TableWildcardProperty","d":"io/burkard/cdk/services/lakeformation/TableWildcardProperty$","k":"object"},
{"l":"io/burkard/cdk/services/lakeformation/TableWildcardProperty$.html","n":"apply","t":"def apply: TableWildcardProperty","d":"io/burkard/cdk/services/lakeformation/TableWildcardProperty$","k":"def"},
{"l":"io/burkard/cdk/services/lakeformation/TableWithColumnsResourceProperty$.html","n":"TableWithColumnsResourceProperty","t":"object TableWithColumnsResourceProperty","d":"io/burkard/cdk/services/lakeformation/TableWithColumnsResourceProperty$","k":"object"},
{"l":"io/burkard/cdk/services/lakeformation/TableWithColumnsResourceProperty$.html","n":"apply","t":"def apply(name: Option[String], columnWildcard: Option[ColumnWildcardProperty], columnNames: Option[List[String]], catalogId: Option[String], databaseName: Option[String]): TableWithColumnsResourceProperty","d":"io/burkard/cdk/services/lakeformation/TableWithColumnsResourceProperty$","k":"def"},
{"l":"docs/index.html","n":"lakeformation","t":"lakeformation","d":"","k":"static"}];

==> aws-cdk-scala-lakeformation_3-0.1.5-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html","n":"lakeformation","t":"lakeformation","d":"","k":"static"},
{"l":"io/burkard/cdk/services/lakeformation.html","n":"io.burkard.cdk.services.lakeformation","t":"package io.burkard.cdk.services.lakeformation","d":"io/burkard/cdk/services/lakeformation","k":"package"},
{"l":"io/burkard/cdk/services/lakeformation/CfnDataLakeSettings$.html","n":"CfnDataLakeSettings","t":"object CfnDataLakeSettings","d":"io/burkard/cdk/services/lakeformation/CfnDataLakeSettings$","k":"object"},
{"l":"io/burkard/cdk/services/lakeformation/CfnDataLakeSettings$.html","n":"apply","t":"def apply(internalResourceId: String, admins: Option[List[_]], trustedResourceOwners: Option[List[String]])(implicit stackCtx: Stack): CfnDataLakeSettings","d":"io/burkard/cdk/services/lakeformation/CfnDataLakeSettings$","k":"def"},
{"l":"io/burkard/cdk/services/lakeformation/CfnDataLakeSettingsProps$.html","n":"CfnDataLakeSettingsProps","t":"object CfnDataLakeSettingsProps","d":"io/burkard/cdk/services/lakeformation/CfnDataLakeSettingsProps$","k":"object"},
{"l":"io/burkard/cdk/services/lakeformation/CfnDataLakeSettingsProps$.html","n":"apply","t":"def apply(admins: Option[List[_]], trustedResourceOwners: Option[List[String]]): CfnDataLakeSettingsProps","d":"io/burkard/cdk/services/lakeformation/CfnDataLakeSettingsProps$","k":"def"},
{"l":"io/burkard/cdk/services/lakeformation/CfnPermissions$.html","n":"CfnPermissions","t":"object CfnPermissions","d":"io/burkard/cdk/services/lakeformation/CfnPermissions$","k":"object"},
{"l":"io/burkard/cdk/services/lakeformation/CfnPermissions$.html","n":"apply","t":"def apply(internalResourceId: String, dataLakePrincipal: DataLakePrincipalProperty, resource: ResourceProperty, permissionsWithGrantOption: Option[List[String]], permissions: Option[List[String]])(implicit stackCtx: Stack): CfnPermissions","d":"io/burkard/cdk/services/lakeformation/CfnPermissions$","k":"def"},
{"l":"io/burkard/cdk/services/lakeformation/CfnPermissionsProps$.html","n":"CfnPermissionsProps","t":"object CfnPermissionsProps","d":"io/burkard/cdk/services/lakeformation/CfnPermissionsProps$","k":"object"},
{"l":"io/burkard/cdk/services/lakeformation/CfnPermissionsProps$.html","n":"apply","t":"def apply(dataLakePrincipal: DataLakePrincipalProperty, resource: ResourceProperty, permissionsWithGrantOption: Option[List[String]], permissions: Option[List[String]]): CfnPermissionsProps","d":"io/burkard/cdk/services/lakeformation/CfnPermissionsProps$","k":"def"},
{"l":"io/burkard/cdk/services/lakeformation/CfnResource$.html","n":"CfnResource","t":"object CfnResource","d":"io/burkard/cdk/services/lakeformation/CfnResource$","k":"object"},
{"l":"io/burkard/cdk/services/lakeformation/CfnResource$.html","n":"apply","t":"def apply(internalResourceId: String, resourceArn: String, useServiceLinkedRole: Boolean, roleArn: Option[String])(implicit stackCtx: Stack): CfnResource","d":"io/burkard/cdk/services/lakeformation/CfnResource$","k":"def"},
{"l":"io/burkard/cdk/services/lakeformation/CfnResourceProps$.html","n":"CfnResourceProps","t":"object CfnResourceProps","d":"io/burkard/cdk/services/lakeformation/CfnResourceProps$","k":"object"},
{"l":"io/burkard/cdk/services/lakeformation/CfnResourceProps$.html","n":"apply","t":"def apply(resourceArn: String, useServiceLinkedRole: Boolean, roleArn: Option[String]): CfnResourceProps","d":"io/burkard/cdk/services/lakeformation/CfnResourceProps$","k":"def"},
{"l":"io/burkard/cdk/services/lakeformation/ColumnWildcardProperty$.html","n":"ColumnWildcardProperty","t":"object ColumnWildcardProperty","d":"io/burkard/cdk/services/lakeformation/ColumnWildcardProperty$","k":"object"},
{"l":"io/burkard/cdk/services/lakeformation/ColumnWildcardProperty$.html","n":"apply","t":"def apply(excludedColumnNames: Option[List[String]]): ColumnWildcardProperty","d":"io/burkard/cdk/services/lakeformation/ColumnWildcardProperty$","k":"def"},
{"l":"io/burkard/cdk/services/lakeformation/DataLakePrincipalProperty$.html","n":"DataLakePrincipalProperty","t":"object DataLakePrincipalProperty","d":"io/burkard/cdk/services/lakeformation/DataLakePrincipalProperty$","k":"object"},
{"l":"io/burkard/cdk/services/lakeformation/DataLakePrincipalProperty$.html","n":"apply","t":"def apply(dataLakePrincipalIdentifier: Option[String]): DataLakePrincipalProperty","d":"io/burkard/cdk/services/lakeformation/DataLakePrincipalProperty$","k":"def"},
{"l":"io/burkard/cdk/services/lakeformation/DataLocationResourceProperty$.html","n":"DataLocationResourceProperty","t":"object DataLocationResourceProperty","d":"io/burkard/cdk/services/lakeformation/DataLocationResourceProperty$","k":"object"},
{"l":"io/burkard/cdk/services/lakeformation/DataLocationResourceProperty$.html","n":"apply","t":"def apply(s3Resource: Option[String], catalogId: Option[String]): DataLocationResourceProperty","d":"io/burkard/cdk/services/lakeformation/DataLocationResourceProperty$","k":"def"},
{"l":"io/burkard/cdk/services/lakeformation/DatabaseResourceProperty$.html","n":"DatabaseResourceProperty","t":"object DatabaseResourceProperty","d":"io/burkard/cdk/services/lakeformation/DatabaseResourceProperty$","k":"object"},
{"l":"io/burkard/cdk/services/lakeformation/DatabaseResourceProperty$.html","n":"apply","t":"def apply(name: Option[String], catalogId: Option[String]): DatabaseResourceProperty","d":"io/burkard/cdk/services/lakeformation/DatabaseResourceProperty$","k":"def"},
{"l":"io/burkard/cdk/services/lakeformation/ResourceProperty$.html","n":"ResourceProperty","t":"object ResourceProperty","d":"io/burkard/cdk/services/lakeformation/ResourceProperty$","k":"object"},
{"l":"io/burkard/cdk/services/lakeformation/ResourceProperty$.html","n":"apply","t":"def apply(dataLocationResource: Option[DataLocationResourceProperty], tableWithColumnsResource: Option[TableWithColumnsResourceProperty], tableResource: Option[TableResourceProperty], databaseResource: Option[DatabaseResourceProperty]): ResourceProperty","d":"io/burkard/cdk/services/lakeformation/ResourceProperty$","k":"def"},
{"l":"io/burkard/cdk/services/lakeformation/TableResourceProperty$.html","n":"TableResourceProperty","t":"object TableResourceProperty","d":"io/burkard/cdk/services/lakeformation/TableResourceProperty$","k":"object"},
{"l":"io/burkard/cdk/services/lakeformation/TableResourceProperty$.html","n":"apply","t":"def apply(name: Option[String], tableWildcard: Option[TableWildcardProperty], catalogId: Option[String], databaseName: Option[String]): TableResourceProperty","d":"io/burkard/cdk/services/lakeformation/TableResourceProperty$","k":"def"},
{"l":"io/burkard/cdk/services/lakeformation/TableWildcardProperty$.html","n":"TableWildcardProperty","t":"object TableWildcardProperty","d":"io/burkard/cdk/services/lakeformation/TableWildcardProperty$","k":"object"},
{"l":"io/burkard/cdk/services/lakeformation/TableWildcardProperty$.html","n":"apply","t":"def apply: TableWildcardProperty","d":"io/burkard/cdk/services/lakeformation/TableWildcardProperty$","k":"def"},
{"l":"io/burkard/cdk/services/lakeformation/TableWithColumnsResourceProperty$.html","n":"TableWithColumnsResourceProperty","t":"object TableWithColumnsResourceProperty","d":"io/burkard/cdk/services/lakeformation/TableWithColumnsResourceProperty$","k":"object"},
{"l":"io/burkard/cdk/services/lakeformation/TableWithColumnsResourceProperty$.html","n":"apply","t":"def apply(name: Option[String], columnWildcard: Option[ColumnWildcardProperty], columnNames: Option[List[String]], catalogId: Option[String], databaseName: Option[String]): TableWithColumnsResourceProperty","d":"io/burkard/cdk/services/lakeformation/TableWithColumnsResourceProperty$","k":"def"},
{"l":"docs/index.html","n":"lakeformation","t":"lakeformation","d":"","k":"static"}];
